@@ -145,6 +145,8 @@ class Options:
     bobView = True
     anaglyph3d = False
     limitFramerate = False
+    i = False
+    optionCount = 8
 
     def __init__(self, minecraft, file):
         self.forward = KeyMapping('Forward', window.key.W)
@@ -195,6 +197,8 @@ class Options:
                     img = Resources.textures[string]
 
                 self.__minecraft.textures.addTextureId(img, id_)
+        elif option == 7:
+            self.i = not self.i
 
         self.__save()
 
@@ -213,6 +217,8 @@ class Options:
             return 'View bobbing: ' + ('ON' if self.bobView else 'OFF')
         elif option == 6:
             return '3d anaglyph: ' + ('ON' if self.anaglyph3d else 'OFF')
+        elif option == 7:
+            return 'Limit framerate: ' + ('ON' if self.i else 'OFF')
 
         return ''
 
@@ -237,6 +243,8 @@ class Options:
                             self.bobView = split[1] == 'true'
                         elif split[0] == 'anaglyph3d':
                             self.anaglyph3d = split[1] == 'true'
+                        elif split[0] == 'limitFramerate':
+                            self.i = split[1] == 'true'
 
                         for binding in self.keys:
                             if split[0] == 'key_' + binding.name:
@@ -254,6 +262,7 @@ class Options:
                 f.write('viewDistance:' + str(self.viewDistance) + '\n')
                 f.write('bobView:' + ('true' if self.bobView else 'false') + '\n')
                 f.write('anaglyph3d:' + ('true' if self.anaglyph3d else 'false') + '\n')
+                f.write('limitFramerate:' + ('true' if self.i else 'false') + '\n')
 
                 for binding in self.keys:
                     f.write('key_' + binding.name + ':' + str(_GL_KEYS[binding.key]) + '\n')
