@@ -8,8 +8,8 @@ class LeafTile(BaseLeafTile):
     def __init__(self, tiles, id_, tex):
         super().__init__(tiles, 18, 22, True)
 
-    def getResourceCount(self):
-        if math.floor(6 * random.random()) == 0:
+    def resourceCount(self):
+        if math.floor(10 * random.random()) == 0:
             return 1
         else:
             return 0
